# Environment (WSL/Linux)

- We are in a Linux environment (inside WSL).
- Do NOT use PowerShell.
- Do NOT use Windows `.exe` binaries.
- Do NOT prefix commands with `wsl bash`.
- Use plain Linux shell commands.
